-- account definition

CREATE TABLE account (
	id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
	email TEXT NOT NULL,
	password TEXT NOT NULL,
	created TEXT DEFAULT (CURRENT_TIMESTAMP) NOT NULL,
	state INTEGER DEFAULT (1) NOT NULL,
	unique(email)
);

CREATE INDEX account_state_IDX ON account (state);


-- document definition

CREATE TABLE document (
	id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
	account_id INTEGER NOT NULL,
	ext_id TEXT NOT NULL,
	title TEXT NOT NULL,
	description TEXT NOT NULL,
	tags TEXT NOT NULL,
	created TEXT NOT NULL DEFAULT CURRENT_TIMESTAMP,
	reference_date TEXT, state INTEGER DEFAULT (1) NOT NULL,
  	CONSTRAINT document_account_FK FOREIGN KEY (account_id) REFERENCES account(id) ON DELETE CASCADE,
	unique(ext_id)
);

CREATE INDEX document_state_IDX ON document (state);


-- file definition

CREATE TABLE file (
	id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
	account_id INTEGER NOT NULL,
	document_id INTEGER DEFAULT null,
	ext_id TEXT NOT NULL,
	filename TEXT NOT NULL,
	file_size INTEGER NOT NULL,
	content BLOB NOT NULL,
	content_type TEXT,
	content_extracted TEXT,
	created TEXT NOT NULL DEFAULT CURRENT_TIMESTAMP, state INTEGER DEFAULT (1) NOT NULL,
  	CONSTRAINT file_account_FK FOREIGN KEY (account_id) REFERENCES account(id) ON DELETE CASCADE,
	CONSTRAINT file_document_FK FOREIGN KEY (document_id) REFERENCES document(id) ON DELETE CASCADE,
	unique(ext_id)
);

CREATE INDEX file_state_IDX ON file (state);